@@ -4,8 +4,10 @@ import os
 import xml.etree.ElementTree as ET
 import numpy as np
 import pandas as pd
+
 import dask
 import dask.array as da
+
 import re
 import ESMF
 import pathlib
@@ -23,6 +25,7 @@ class GeoAccessor:
     def __init__(self, xarray_obj):
         self._obj = xarray_obj
 
+
     def to_raster(self, var=None, crs_out=None):
         """
         Accessible from the xarray object, e.g., ``df.chm.to_raster(...)``. This allows for converting the entire data array into georeferenced tiffs.
@@ -34,27 +37,22 @@ class GeoAccessor:
         :return:
         """
 
-        def _dowork(d, crs_in, crs_out=None):
+
+        def _dowork_toraster(d, crs_in, crs_out=None):
             name = d.name
 
             time = str(d.time.values[0]).split('.')[0]
             d = d.rio.write_nodata(-9999)
-
+            dxdy = d.coords['dxdy'].values
             if crs_out is not None:
                 tmp = d.squeeze().drop('lat').drop('lon').drop('time')
                 tmp.rio.set_crs(crs_in)
                 tmp = tmp.rio.reproject(crs_out)
             else:
                 tmp = d
-
-            tmp_tiff = f'{name}_{time}.tif'
+            tmp_tiff = f'{name}_{dxdy}x{dxdy}_{time}.tif'
             tmp.rio.to_raster(tmp_tiff)
 
-            # exec = f"""{gdalwarp} -t_srs EPSG:26911 -srcnodata '-9999' {tmp_tiff}  output_{var}_{time}.tif"""
-            # subprocess.check_call([exec], shell=True)
-
-            # os.remove(tmp_tiff)
-
             return d
 
         if var is None:
@@ -62,11 +60,15 @@ class GeoAccessor:
         elif var is not isinstance(object, list):
             var = [var]
 
+        work = []
         for v in var:
-            print(v)
             df = self._obj[v]
-            mapped = xr.map_blocks(_dowork, df, kwargs={'crs_in': self._obj.rio.crs, 'crs_out': crs_out }, template=df)
-            mapped.compute()
+            mapped = xr.map_blocks(_dowork_toraster, df, kwargs={'crs_in': self._obj.rio.crs, 'crs_out': crs_out }, template=df)
+            work.append(mapped)
+            # mapped.compute()
+
+        dask.compute(*work)
+
 
 def _get_shape(mesh, dxdy):
     # number of cells @ this dxdy
@@ -269,6 +271,14 @@ def vtu_to_xarray(fname, dxdy=30, variables=None):
     ds.coords['lon'] = (('y', 'x'), lon)
     ds.coords['lat'] = (('y', 'x'), lat)
 
+    # Because the geo accessor can so easily lose information, set it like this so it is easily obtained
+    ds = ds.assign_coords({'dxdy': dxdy})
+
+    # sets internal rio crs
+    ds = ds.rio.set_crs(proj4)
+
+    # writes CRS in a CF compliant manner
+    ds = ds.rio.write_crs(proj4)
 
     return ds
 
@@ -385,10 +395,10 @@ def pvd_to_xarray(fname, dxdy=50, variables=None):
 
         # print(v)
         # This prevents pickling
-        vtu = _load_vtu(v)
+        # vtu = _load_vtu(v)
 
         for var in variables:
-            # vtu = _load_vtu(v)  # can done here to pickle, but then will end up writting all variables as bands
+            vtu = _load_vtu(v)  # can done here to pickle, but then will end up being a bit more costly
             df = _regrid_mesh_to_grid(vtu, dxdy, var, None, None)
             d = da.from_delayed(df,
                                 shape=shape,
@@ -398,6 +408,7 @@ def pvd_to_xarray(fname, dxdy=50, variables=None):
                                coords={'y': y_center,
                                        'x': x_center},
                                dims=['y', 'x'])
+
             delayed_vtu[var].append(tmp)
 
     end_time = np.datetime64(int(timesteps[-1].get('timestep')), 's')
@@ -422,6 +433,10 @@ def pvd_to_xarray(fname, dxdy=50, variables=None):
     ds.coords['lon'] = (('y', 'x'), lon)
     ds.coords['lat'] = (('y', 'x'), lat)
 
+    # Because the geo accessor can so easily lose information, set it like this so it is easily obtained
+    ds = ds.assign_coords({'dxdy': dxdy})
+
+
     # we need to be really careful when do this assignment as these attrs can be easily lost, see:
     # https://github.com/corteva/rioxarray/issues/427
     # https://corteva.github.io/rioxarray/stable/getting_started/crs_management.html
